/**
 * User download manager
 *
 * @module package/quiqqer/user-downloads/bin/js/backend/classes/UserDownloads
 * @author www.pcsg.de (Patrick Müller)
 */
define('package/quiqqer/user-downloads/bin/js/backend/classes/UserDownloads', [
    'Ajax'
], function(QUIAjax) {
    'use strict';

    const pkg = 'quiqqer/user-downloads';

    return new Class({

        Type: 'package/quiqqer/user-downloads/bin/js/backend/classes/UserDownloads',

        /**
         * Get list of user downloads
         *
         * @param {number} uid - QUIQQER user id
         * @return {Promise}
         */
        getList: function(uid) {
            return new Promise(function(resolve, reject) {
                QUIAjax.get('package_quiqqer_user-downloads_ajax_backend_getList', resolve, {
                    'package': pkg,
                    uid: uid,
                    onError: reject
                });
            });
        },

        /**
         * Create a user download entry
         *
         * @param {number} uid - QUIQQER user id
         * @param {Object} Data - Download entry data
         * @return {Promise}
         */
        create: function(uid, Data) {
            return new Promise(function(resolve, reject) {
                QUIAjax.post('package_quiqqer_user-downloads_ajax_backend_create', resolve, {
                    'package': pkg,
                    uid: uid,
                    data: JSON.encode(Data),
                    onError: reject
                });
            });
        },

        /**
         * Update a user download entry
         *
         * @param {number} id - Download entry id
         * @param {Object} Data - Download entry data
         * @return {Promise}
         */
        update: function(id, Data) {
            return new Promise(function(resolve, reject) {
                QUIAjax.post('package_quiqqer_user-downloads_ajax_backend_update', resolve, {
                    'package': pkg,
                    id: id,
                    data: JSON.encode(Data),
                    onError: reject
                });
            });
        },

        /**
         * Delete user download entries
         *
         * @param {Array} ids - Download entry ids
         * @return {Promise}
         */
        delete: function(ids) {
            return new Promise(function(resolve, reject) {
                QUIAjax.post('package_quiqqer_user-downloads_ajax_backend_delete', resolve, {
                    'package': pkg,
                    ids: JSON.encode(ids),
                    onError: reject
                });
            });
        }
    });
});
